/**************** review_part css start ****************/
.review_part {
  @include background("../img/review_bg.png");
  position: relative;
  z-index: 1;

  &:after {
    position: absolute;
    content: "";
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    background-color: rgb(34, 31, 63);
    opacity: 0.8;
    z-index: -1;
  }

  .client_review_single {
    .Quote {
      width: 59px;
      height: auto;
      margin: 0 auto;
      padding-bottom: 42px;
    }
  }

  .client_img {
    @media #{$small_mobile} {
      display: block;
      width: 100%;
      padding-top: 0px;

    }

    @media #{$large_mobile} {
      display: block;
      width: 100%;
      padding-top: 0px;
    }

    @media #{$tab_device} {
      display: block;
      width: 100%;
      padding-top: 0px;
    }

    @media #{$medium_device} {}

    img {
      max-width: 75px;
      max-height: 75px;
      margin: 0 auto;
      text-align: center;
      margin-top: 45px;
    }
  }

  .client_review_part {
    position: relative;
    z-index: 1;
  }

  .client_review_single {
    text-align: center;

    .client_review_text {
      padding-left: 50px;

      @media #{$small_mobile} {
        padding-left: 0px;
      }

      @media #{$large_mobile} {
        padding-left: 0px;
      }

      @media #{$tab_device} {
        padding-left: 0px
      }

      @media #{$medium_device} {}
      p {
        font-size: 18px;
        font-family: $font_stack_1;
        color: $white_color;
        line-height: 1.9;

        @media #{$small_mobile} {
          font-size: 16px;
        }

        @media #{$large_mobile} {
          font-size: 16px;
        }

        @media #{$tab_device} {
          font-size: 16px;
        }

        @media #{$medium_device} {}
      }

    }
  }

  h4 {
    margin-top: 30px;
    font-size: 22px;
    font-weight: 700;
    color: $white_color;
    margin-bottom: 50px;
    @media #{$small_mobile} {
      margin-top: 20px;
      font-size: 20px;
      margin-bottom: 20px;
    }

    @media #{$large_mobile} {
      margin-top: 20px;
      font-size: 20px;
      margin-bottom: 20px;
    }

    @media #{$tab_device} {
      margin-top: 20px;
      font-size: 20px;
      margin-bottom: 20px;
    }

    @media #{$medium_device} {}

    span {
      font-family: $font_stack_2;
      font-size: 14px;
      color: $white_color;
      font-weight: 400;
    }
  }

  .owl-dots {
    left: 0;
    right: 0;
    margin: 0 auto;
    text-align: center;
    top: 60px;

    @media #{$small_mobile} {
      padding-left: 0px;
    }

    @media #{$large_mobile} {
      padding-left: 0px;
    }

    @media #{$tab_device} {
      padding-left: 0px;
    }

    @media #{$medium_device} {}

    button.owl-dot {
      width: 10px;
      height: 10px;
      border-radius: 50%;
      display: inline-block;
      margin: 0 8px;
      position: relative;
      z-index: 1;
      background-color: $white_color;
      background-color: rgba(255, 255, 255, .5);

      &.active {
        border-radius: 50%;
        background-color: rgb(241, 133, 133);
        width: 11px;
        height: 11px;
      }


      &:focus {
        outline: none;
      }
    }
  }
}